## Setting the environment

Set values in `config.json` based on your specific database
Currently the application supports `mssql` and `mysql` databases by setting the `databaseType` value

Default configuration is below in case something is accidentally changed or deleted

```
{
  "databaseType": "mssql",
  "databaseHost": "localhost,
  "databaseUser": "db_user",
  "databasePassword": "db_password",
  "databaseName": "db_name",
  "databasePort": 1433,

  "capacityHost": "value_provided_by_capacity",
  "capacitySecret": "value_provided_by_capacity"
}
```

`capacityHost` and `capacitySecret` are provided by Capacity and should not be changed, these values are required for the server to connect to Capacity's servers.

## Starting the server

The command `node server.js` will automatically start the server listening at port 4201 and start displaying logs, the port can be overriden by passing a `PORT` value with the command when running the server -- for example `PORT=4400 node server.js`

The application assumes it is being started from the directory in which `server.js` resides, so do not issue the start command from a different folder.

Upon server startup it will attempt to connect with Capacity's server and will log a message upon a successful connection or if there is a connection error

There is a configuration UI available at `/configuration` that can be accessed via a web browser to assist in creating queries, but manual configuration is also possible. If using the default port, the URL would be `http://localhost:4201/configuration`

## Queries

Queries are stored as flat `json` files in the included `queries` directory with the following schema:

```json
{
  "inputs": [{ "name": "string", "type": "string" }],
  "outputs": [{ "name": "string", "type": "string" }]
}
```

Query strings must be defined using `@variable_name` syntax, and any included variables in a query string must be defined in the `inputs` array

For example, if I want to query my `users` table by name, and return the `id` and `name` of the result, my query might look something like:

`get_user_by_name.json`

```json
{
  "inputs": [{ "name": "name", "type": "VarChar" }],
  "outputs": [
    { "name": "id", "type": "Int" },
    { "name": "name", "type": "VarChar" }
  ],
  "query": "select * from users where name = @name"
}
```

Capacity does not have access via the persistent connection to the values stored in the `query` field or any values placed in the `config.json` file besides those we provide.

Capacity can get a list of all file names, which are used to send commands, as well as each file's `inputs` and `outputs` array.

The server logs each incoming request over the persistent connection as well as the raw data contained in each request and the raw data being returned to Capacity
